@@ -37,6 +37,7 @@ class Output::Private
         id(0),
         type(Unknown),
         rotation(None),
+        scale(1.0),
         connected(false),
         enabled(false),
         primary(false),
@@ -56,6 +57,7 @@ class Output::Private
         pos(other.pos),
         size(other.size),
         rotation(other.rotation),
+        scale(other.scale),
         connected(other.connected),
         enabled(other.enabled),
         primary(other.primary)
@@ -69,6 +71,7 @@ class Output::Private
     }
 
     QString biggestMode(const ModeList& modes) const;
+    bool compareModeList(const ModeList& before, const ModeList& after);
 
     int id;
     QString name;
@@ -83,6 +86,7 @@ class Output::Private
     QPoint pos;
     QSize size;
     Rotation rotation;
+    qreal scale;
     bool connected;
     bool enabled;
     bool primary;
@@ -90,6 +94,32 @@ class Output::Private
     mutable QPointer<Edid> edid;
 };
 
+bool Output::Private::compareModeList(const ModeList& before, const ModeList &after)
+{
+    if (before.keys() != after.keys()) {
+        return false;
+    }
+    for (const QString &key : before.keys()) {
+        const auto mb = before.value(key);
+        const auto ma = after.value(key);
+        if (mb->id() != ma->id()) {
+            return false;
+        }
+        if (mb->size() != ma->size()) {
+            return false;
+        }
+        if (mb->refreshRate() != ma->refreshRate()) {
+            return false;
+        }
+        if (mb->name() != ma->name()) {
+            return false;
+        }
+    }
+    // They're the same
+    return true;
+}
+
+
 QString Output::Private::biggestMode(const ModeList& modes) const
 {
     int area, total = 0;
@@ -221,7 +251,12 @@ ModeList Output::modes() const
 
 void Output::setModes(const ModeList &modes)
 {
+    bool changed = !d->compareModeList(d->modeList, modes);
     d->modeList = modes;
+    if (changed) {
+        emit modesChanged();
+        emit outputChanged();
+    }
 }
 
 QString Output::currentModeId() const
@@ -345,6 +380,20 @@ void Output::setRotation(Output::Rotation rotation)
     Q_EMIT rotationChanged();
 }
 
+qreal Output::scale() const
+{
+    return d->scale;
+}
+
+void Output::setScale(qreal factor)
+{
+    if (d->scale == factor) {
+        return;
+    }
+    d->scale = factor;
+    emit scaleChanged();
+}
+
 bool Output::isConnected() const
 {
     return d->connected;
@@ -494,8 +543,10 @@ void Output::apply(const OutputPtr& other)
         changes << &Output::clonesChanged;
         setClones(other->d->clones);;
     }
+    if (!d->compareModeList(d->modeList, other->d->modeList)) {
+        changes << &Output::outputChanged;
+    }
 
-    // Non-notifyable changes
     setPreferredModes(other->d->preferredModes);
     ModeList modes;
     Q_FOREACH (const ModePtr &otherMode, other->modes()) {
@@ -503,6 +554,7 @@ void Output::apply(const OutputPtr& other)
     }
     setModes(modes);
 
+    // Non-notifyable changes
     if (other->d->edid) {
         delete d->edid;
         d->edid = other->d->edid->clone();
